@@ -55,21 +55,6 @@
 
 config_t lldpad_cfg;
 
-/*
- * config_ifkey - Generates a config key
- *
- * Given an interface name this functions generates
- * a key (based on interface's index) suitable
- * to pass to libconfig.
- *
- */
-void config_ifkey(const char *name, char *ifkey) {
-	int index = if_nametoindex(name);
-	
-	if(index)
-		sprintf(ifkey, "if%d", index);
-}
-
 /*
  * init_cfg - initialze the global lldpad_cfg via config_init
  *
@@ -466,15 +451,14 @@ static int lookup_config_value(char *path, union cfg_get v, int type)
 int get_config_setting(const char *ifname, int agenttype, char *path,
 		       union cfg_get v, int type)
 {
-	char p[1024], ifkey[IFNAMSIZ];
+	char p[1024];
 	int rval = CONFIG_FALSE;
 	const char *section = agent_type2section(agenttype);
 
 	/* look for setting in section->ifname area first */
 	if (ifname) {
-		config_ifkey(ifname, ifkey);
 		snprintf(p, sizeof(p), "%s.%s.%s",
-			 section, ifkey, path);
+			 section, ifname, path);
 		rval = lookup_config_value(p, v, type);
 	}
 
@@ -491,16 +475,15 @@ int get_config_setting(const char *ifname, int agenttype, char *path,
 int remove_config_setting(const char *ifname, int agenttype, char *parent,
 			  char *name)
 {
-	char p[1024], ifkey[IFNAMSIZ];
+	char p[1024];
 	int rval = CONFIG_FALSE;
 	config_setting_t *setting = NULL;
 	const char *section = agent_type2section(agenttype);
 
 	/* look for setting in section->ifname area first */
-	if (ifname) { 
-		config_ifkey(ifname, ifkey);
+	if (ifname) {
 		snprintf(p, sizeof(p), "%s.%s.%s",
-			 section, ifkey, parent);
+			 section, ifname, parent);
 		setting = config_lookup(&lldpad_cfg, p);
 	}
 
@@ -587,17 +570,15 @@ int set_config_setting(const char *ifname, int agenttype, char *path,
 		       union cfg_set v, int type)
 {
 	config_setting_t *setting = NULL;
-	char p[1024], ifkey[IFNAMSIZ];
+	char p[1024];
 	int rval = cmd_success;
 	const char *section = agent_type2section(agenttype);
 
 	LLDPAD_DBG("%s(%i): \n", __func__, __LINE__);
 
-	if (strlen(ifname)){
-		config_ifkey(ifname, ifkey);
+	if (strlen(ifname))
 		snprintf(p, sizeof(p), "%s.%s.%s",
-			 section, ifkey, path);
-	}
+			 section, ifname, path);
 	else
 		snprintf(p, sizeof(p), "%s.%s.%s",
 			 section, LLDP_COMMON, path);
